@@ -1,9 +1,8 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from entity_emailer.views import EmailView
 
 
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(r'^([0-9a-z\-]+)/$', EmailView.as_view(), name='entity_emailer.email'),
-)
+]
